About
=====

SymPy Development Team
----------------------

SymPy is a team project and it was developed by a lot of people.

Here is a list of contributors together with what they do, (and in some cases links to their
wiki pages), where they describe in
more details what they do and what they are interested in (some people didn't
want to be mentioned here, so see our repository history for a full list).

#. Ondřej Čertík: started the project in 2006, on Jan 4, 2011 passed the project leadership to Aaron Meurer
#. Fabian Pedregosa: everything, reviewing patches, releases, general advice (issues and mailinglist), GSoC 2009
#. Jurjen N.E. Bos: pretty printing and other patches
#. Mateusz Paprocki: GSoC 2007, concrete math module, integration module, new core integration, a lot of patches, general advice, new polynomial module, improvements to solvers, simplifications, patch review
#. Marc-Etienne M.Leveille: matrix patch
#. Brian Jorgensen: GSoC 2007, plotting module and related things, patches
#. Jason Gedge: GSoC 2007, geometry module, a lot of patches and fixes, new core integration
#. Robert Schwarz: GSoC 2007, polynomials module, patches
#. `Pearu Peterson <https://github.com/sympy/sympy/wiki/Pearu-Peterson>`_: new core, sympycore project, general advice (issues and mailinglist)
#. `Fredrik Johansson <https://github.com/sympy/sympy/wiki/Fredrik-Johansson>`_: mpmath project and its integration in SymPy, number theory, combinatorial functions, products & summation, statistics, units, patches, documentation, general advice (issues and mailinglist)
#. Chris Wu: GSoC 2007, linear algebra module
#. Ulrich Hecht: pattern matching and other patches
#. Goutham Lakshminarayan: number theory functions
#. David Lawrence: GHOP, Mathematica parser, square root denesting
#. Jaroslaw Tworek: GHOP, sympify AST implementation, sqrt() refactoring, maxima parser and other patches
#. David Marek: GHOP, derivative evaluation patch, int(NumberSymbol) fix
#. Bernhard R. Link: documentation patch
#. Andrej Tokarčík: GHOP, python printer
#. Or Dvory: GHOP, documentation
#. Saroj Adhikari: bug fixes
#. Pauli Virtanen: bug fix
#. Robert Kern: bug fix, common subexpression elimination
#. James Aspnes: bug fixes
#. Nimish Telang: multivariate lambdas
#. Abderrahim Kitouni: pretty printing + complex expansion bug fixes
#. Pan Peng: ode solvers patch
#. Friedrich Hagedorn: many bug fixes, refactorings and new features added
#. Elrond der Elbenfuerst: pretty printing fix
#. Rizgar Mella: BBP formula for pi calculating algorithm
#. Felix Kaiser: documentation + whitespace testing patches
#. Roberto Nobrega: several pretty printing patches
#. David Roberts: latex printing patches
#. Sebastian Krämer: implemented lambdify/numpy/mpmath cooperation, bug fixes, refactoring, lambdifying of matrices, large printing refactoring and bugfixes
#. Vinzent Steinberg: docstring patches, a lot of bug fixes, nsolve (nonlinear equation systems solver), compiling functions to machine code, patches review
#. Riccardo Gori: improvements and speedups to matrices, many bug fixes
#. Case Van Horsen: implemented optional support for gmpy in mpmath
#. Štěpán Roučka: a lot of bug fixes all over SymPy (matrix, simplification, limits, series, ...)
#. Ali Raza Syed: pretty printing/isympy on windows fix
#. Stefano Maggiolo: many bug fixes, polishings and improvements
#. Robert Cimrman: matrix patches
#. Bastian Weber: latex printing patches
#. Sebastian Krause: match patches
#. Sebastian Kreft: latex printing patches, Dirac delta function, other fixes
#. Dan (coolg49964): documentation fixes
#. Alan Bromborsky: geometric algebra modules
#. Boris Timokhin: matrix fixes
#. Robert (average.programmer): initial piecewise function patch
#. Andy R. Terrel: piecewise function polishing and other patches
#. Hubert Tsang: LaTeX printing fixes
#. Konrad Meyer: policy patch
#. Henrik Johansson: matrix zero finder patch
#. Priit Laes: line integrals, cleanups in ODE, tests added
#. Freddie Witherden: trigonometric simplifications fixes, LaTeX printer improvements
#. Brian E. Granger: second quantization physics module
#. Andrew Straw: lambdify() improvements
#. Kaifeng Zhu: factorint() fix
#. Ted Horst: Basic.__call__() fix, pretty printing fix
#. Andrew Docherty: Fix to series
#. Akshay Srinivasan: printing fix, improvements to integration
#. Aaron Meurer: ODE solvers (GSoC 2009), The Risch Algorithm for integration (GSoC 2010), other fixes, project leader as of Jan 4, 2011
#. Barry Wardell: implement series as function, several tests added
#. Tomasz Buchert: ccode printing fixes, code quality concerning exceptions, documentation
#. Vinay Kumar: polygamma tests
#. Johann Cohen-Tanugi: commutative diff tests
#. Jochen Voss: a test for the @cachit decorator and several other fixes
#. Luke Peterson: improve solve() to handle Derivatives
#. Chris Smith: improvements to solvers, many bug fixes, documentation and test improvements
#. Thomas Sidoti: MathML printer improvements
#. Florian Mickler: reimplementation of convex_hull, several geometry module fixes
#. Nicolas Pourcelot: Infinity comparison fixes, latex fixes
#. Ben Goodrich: Matrix.jacobian() function improvements and fixes
#. Toon Verstraelen: code generation module, latex printing improvements
#. Ronan Lamy: test coverage script; limit, expansion and other fixes and improvements; cleanup
#. James Abbatiello: fixes tests on windows
#. Ryan Krauss: fixes could_extract_minus_sign(), latex fixes and improvements
#. Bill Flynn: substitution fixes
#. Kevin Goodsell: Fix to Integer/Rational
#. Jorn Baayen: improvements to piecewise functions and latex printing, bug fixes
#. Eh Tan: improve trigonometric simplification
#. Renato Coutinho: derivative improvements
#. Oscar Benjamin: latex printer fix, gcd bug fix
#. Øyvind Jensen: implemented coupled cluster expansion and wick theorem, improvements to assumptions, bugfixes
#. Julio Idichekop Filho: indentation fixes, docstring improvements
#. Łukasz Pankowski: fix matrix multiplication with numpy scalars
#. Chu-Ching Huang: fix 3d plotting example
#. Fernando Perez: symarray() implemented
#. Raffaele De Feo: fix non-commutative expansion
#. Christian Muise: fixes to logic module
#. Matt Curry: GSoC 2010 project (symbolic quantum mechanics)
#. Kazuo Thow: cleanup pretty printing tests
#. Christian Schubert: Fix to sympify()
#. Jezreel Ng: fix hyperbolic functions rewrite
#. James Pearson: Py3k related fixes
#. Matthew Brett: fixes to lambdify
#. Addison Cugini: GSoC 2010 project (quantum computing)
#. Nicholas J.S. Kinar: improved documentation about "Immutability of Expressions"
#. Harold Erbin: Geometry related work
#. Thomas Dixon: fix a limit bug
#. Cristóvão Sousa: implements _sage_ method for sign function.
#. Andre de Fortier Smit: doctests in matrices improved
#. Mark Dewing: Fixes to Integral/Sum, MathML work
#. Alexey U. Gudchenko: various work in matrices
#. Gary Kerr: fix examples, docs
#. Sherjil Ozair: fixes to SparseMatrix
#. Oleksandr Gituliar: fixes to Matrix
#. Sean Vig: Quantum improvement
#. Prafullkumar P. Tale: fixed plotting documentation
#. Vladimir Perić: fix some Python 3 issues
#. Tom Bachmann: fixes to Real
#. Yuri Karadzhov: improvements to hyperbolic identities
#. Vladimir Lagunov: improvements to the geometry module
#. Matthew Rocklin: stats, sets, matrix expressions
#. Saptarshi Mandal: Test for an integral
#. Gilbert Gede: Tests for solvers
#. Anatolii Koval: Infinite 1D box example
#. Tomo Lazovich: fixes to quantum operators
#. Pavel Fedotov: fix to is_number
#. Kibeom Kim: fixes to cse function and preorder_traversal
#. Gregory Ksionda: fixes to Integral instantiation
#. Tomáš Bambas: prettier printing of examples
#. Jeremias Yehdegho: fixes to the nthoery module
#. Jack McCaffery: fixes to asin and acos
#. Raymond Wong: Quantum work
#. Luca Weihs: improvements to the geometry module
#. Shai 'Deshe' Wyborski: fix to numeric evaluation of hypergeometric sums
#. Thomas Wiecki: Fix Sum.diff
#. Óscar Nájera: better Laguerre polynomial generator
#. Mario Pernici: faster algorithm for computing Groebner bases
#. Benjamin McDonald: Fix bug in geometry
#. Sam Magura: Improvements to Plot.saveimage
#. Stefan Krastanov: Make Pyglet an external dependency
#. Bradley Froehle: Fix shell command to generate modules in setup.py
#. Min Ragan-Kelley: Fix isympy to work with IPython 0.11
#. Nikhil Sarda: Fix to combinatorics/prufer
#. Emma Hogan: Fixes to the documentation
#. Jason Moore: Fixes to the mechanics module
#. Julien Rioux: Fix behavior of some deprecated methods
#. Roberto Colistete, Jr.: Add num_columns option to the pretty printer
#. Raoul Bourquin: Implement Euler numbers
#. Gert-Ludwig Ingold: Correct derivative of coth
#. Srinivas Vasudevan: Implementation of Catalan numbers
#. Miha Marolt: Add numpydoc extension to the Sphinx docs, fix ode_order
#. Tim Lahey: Rotation matrices
#. Luis Garcia: update examples in symarry
#. Matt Rajca: Code quality fixes
#. David Li: Documentation fixes
#. David Ju: Increase test coverage, fixes to KroneckerDelta
#. Alexandr Gudulin: Code quality fixes
#. Bilal Akhtar: isympy man page
#. Grzegorz Świrski: Fix to latex(), MacPorts portfile
#. Matt Habel: SymPy-wide pyflakes editing
#. Nikolay Lazarov: Translation of the tutorial to Bulgarian
#. Nichita Utiu: Add pretty printing to Product()
#. Tristan Hume: Fixes to test_lambdify.py
#. Imran Ahmed Manzoor: Fixes to the test runner
#. Steve Anton: pyflakes cleanup of various modules, documentation fixes for logic
#. Sam Sleight: Fixes to geometry documentation
#. tsmars15: Fixes to code quality
#. Chancellor Arkantos: Fixes to the logo
#. Stepan Simsa: Translation of the tutorial to Czech
#. Tobias Lenz: Unicode pretty printer for Sum
#. Siddhanathan Shanmugam: Documentation fixes for the Physics module
#. Tiffany Zhu: Improved the latex() docstring
#. Alexey Subach: Translation of the tutorial to Russian
#. Joan Creus: Improvements to the test runner
#. Geoffry Song: Improve code coverage
#. Puneeth Chaganti: Fix for the tutorial
#. Marcin Kostrzewa: SymPy Cheatsheet
#. Jim Zhang: Fixes to AUTHORS and .mailmap
#. Natalia Nawara: Fixes to Product()
#. vishal: Update the Czech tutorial translation to use a .po file
#. Shruti Mangipudi: added See Also documentation to Matrices
#. Davy Mao: Documentation
#. Swapnil Agarwal: added See Also documentation to ntheory, functions
#. Kendhia: Add XFAIL tests
#. jerryma1121: See Also documentation for geometry
#. Joachim Durchholz: corrected spacing issues identified by PyDev
#. Martin Povišer: fix problem with rationaltools
#. Siddhant Jain: See Also documentation for functions/special
#. Kevin Hunter: Improvements to the inequality classes
#. Michael Mayorov: Improvement to series
#. Nathan Alison: Additions to the stats module
#. Christian Bühler: remove use of set_main() in GA
#. Carsten Knoll: improvement to preview()
#. M R Bharath: modified use of int_tested, improvement to Permutation
#. Matthias Toews: File permissions
#. Sergiu Ivanov: Fixes to zoo, SymPyDeprecationWarning
#. Jorge E. Cardona: Cleanup in polys
#. Sanket Agarwal: Rewrite coverage_doctest.py script
#. Manoj Babu K.: Improve gamma function
#. Sai Nikhil: Fix to Heavyside with complex arguments
#. Aleksandar Makelov: Fixes regarding the dihedral group generator
#. Raphael Michel: German translation of the tutorial
#. Sachin Irukula: Changes to allow Dict sorting
#. Ashwini Oruganti: Changes to Pow printing
#. Andreas Kloeckner: Fix to cse()
#. Prateek Papriwal: improve summation documentation
#. Arpit Goyal: Improvements to Integral and Sum
#. Angadh Nanjangud: in physics.mechanics, added a function and tests for the parallel axis theorem
#. Comer Duncan: added dual, is_antisymmetric, and det_lu_decomposition to matrices.py
#. Jens H. Nielsen: added sets to modules listing, update IPython printing extension
#. Joseph Dougherty: modified whitespace cleaning to remove multiple newlines at eof
#. marshall2389: Spelling correction
#. Guru Devanla: Implemented quantum density operator
#. George Waksman: Implemented JavaScript code printer and MathML printer
#. Angus Griffith: Fix bug in rsolve
#. Timothy Reluga: Rewrite trigonometric functions as rationals
#. Brian Stephanik: Test for a bug in fcode
#. Ljubiša Moćić: Serbian translation of the tutorial
#. Piotr Korgul: Polish translation of the tutorial
#. Rom le Clair: French translation of the tutorial
#. Alexandr Popov: Fixes to Pauli algebra
#. Saurabh Jha: Work on Kauers algorithm
#. Tarun Gaba: Implemented some trigonometric integrals
#. Takafumi Arakaki: Add info target to the doc Makefile
#. Alexander Eberspächer: correct typo in aboutus.rst
#. Sachin Joglekar: Simplification of logic expressions to SOP and POS forms
#. Tyler Pirtle: Fix improperly formatted error message
#. Vasily Povalyaev: Fix latex(Min)
#. Colleen Lee: replace uses of fnan with S.NaN
#. Niklas Thörne: Fix links in the docs
#. Huijun Mai: Chinese translation of the tutorial
#. Marek Šuppa: Improvements to symbols, tests
#. Prasoon Shukla: Bug fixes
#. Sergey B Kirpichev: Bug fixes
#. Stefen Yin: Fixes to the mechanics module
#. Thomas Hisch: Improvements to the printing module
#. Matthew Hoff: Addition to quantum module
#. Madeleine Ball: Bug fix
#. Case Van Horsen: Fixes to gmpy support
#. Mary Clark: Improvements to the group theory module
#. Rishabh Dixit: Bug fixes
#. Acebulf: Typos
#. Manoj Kumar: Bug fix
#. Akshit Agarwal: improvements to range handling in symbols
#. CJ Carey: Fix for limits of factorials
#. Patrick Lacasse: Fix for Piecewise.subs
#. Ananya H: Bug fix
#. Tarang Patel: added test for issue 1640
#. Christopher Dembia: improvements to mecahanics documentation
#. Benjamin Fishbein: added rank method to Matrix
#. Sean Ge: made KroneckerDelta arguments canonically ordered
#. Ankit Agrawal: Statistical moments
#. Amit Jamadagni: qapply Rotation to spin states
#. Björn Dahlgren: Documentation fix
#. Christophe Saint-Jean: fixed and added metrics to galgebra
#. Demian Wassermann: fix to ccode printer for Piecewise
#. Khagesh Patel: Addition to matrix expressions
#. Stephen Loo: Update minimum gmpy2 version
#. hm: Fixes to printing
#. Katja Sophie Hotz: use expansion in minpoly
#. Varun Joshi: Addition to functions
#. Chetna Gupta: Improvements to the Risch integration algorithm
#. Thilina Rathnayake: Fix to the matrices
#. Shravas K Rao: Implement prev_lexicographic and next_lexicographic
#. Max Hutchinson: Fix to HadamardProduct
#. Matthew Tadd: fix definition in units module
#. Alexander Hirzel: Updates to ODE docs
#. Randy Heydon: improve collinear point detection
#. Ramana Venkata: improvements to special functions
#. Oliver Lee: improvements to mechanics
#. Seshagiri Prabhu: hardcoded 3x3 determinant
#. Pradyumna: Fix to printing
#. Erik Welch: Fix a warning
#. Eric Nelson: Fixes to printing
#. Roland Puntaier: Improve App Engine support
#. Chris Conley: Use warnings instead of prints
#. Tim Swast: Help with pull requests and IPython
#. Dmitry Batkovich: Fix to series
#. Francesco Bonazzi: Improvements to matrices and tensors
#. Yuriy Demidov: Add examples from "Review of CAS mathematical capabilities"
#. Rick Muller: Implementation of quantum circuit plotting
#. Manish Gill: Fix infinite loop in Matrix constructor
#. Markus Müller: Add Jordan form for matrices
#. Amit Saha: Fixes to documentation
#. Jeremy: Bug fix
#. QuaBoo: Optimizations in ntheory
#. Stefan van der Walt: Fixes to mechanics module
#. David Joyner: Cryptography module
#. Lars Buitinck: Bug fix
#. Alkiviadis G. Akritas: Add a reference
#. Vinit Ravishankar: fix iterables documentation
#. Mike Boyle: Additions to the printing system
#. Heiner Kirchhoffer: PythonRational int conversion fix
#. Pablo Puente: Test cases from Wester paper
#. James Fiedler: Bug fix
#. Harsh Gupta: Bug fix
#. Tuomas Airaksinen: is_real for besselx
#. rathmann: fix some Python 2/3 issues

Up-to-date list in the order of the first contribution is given in the `AUTHORS
<https://github.com/sympy/sympy/blob/master/AUTHORS>`_ file.

You can find a brief history of SymPy in the README.

Financial and Infrastructure Support
------------------------------------

* `Google <http://www.google.com/corporate/>`_: SymPy has received generous
  financial support from Google in various years through the `Google Summer of
  Code <http://www.google-melange.com/>`_ program by providing stipends:

  * in 2007 for 5 students (`GSoC 2007 <https://github.com/sympy/sympy/wiki/GSoC-2007-Report>`_)
  * in 2008 for 1 student (`GSoC 2008 <https://github.com/sympy/sympy/wiki/GSoC-2008-report>`_)
  * in 2009 for 5 students (`GSoC 2009 <https://github.com/sympy/sympy/wiki/GSoC-2009-report>`_)
  * in 2010 for 5 students (`GSoC 2010 <https://github.com/sympy/sympy/wiki/GSoC-2010-report>`_)
  * in 2011 for 9 students (`GSoC 2011 <https://github.com/sympy/sympy/wiki/Gsoc-2011-report>`_)
  * in 2012 for 6 students (`GSoC 2012 <https://github.com/sympy/sympy/wiki/Gsoc-2012-report>`_)
  * in 2013 for 7 students (`GSoC 2013 <https://github.com/sympy/sympy/wiki/Gsoc-2013-report>`_)

* `Python Software Foundation (PSF) <http://www.python.org/psf/>`_ has hosted
  various GSoC students over the years:

  * 3 GSoC 2007 students (Brian, Robert and Jason)
  * 1 GSoC 2008 student (Fredrik)
  * 2 GSoC 2009 students (Freddie and Priit)
  * 4 GSoC 2010 students (Aaron, Christian, Matthew and Øyvind)

* `Portland State University (PSU) <http://www.pdx.edu/>`_ has hosted following
  GSoC students:

  * 1 student (Chris) in 2007
  * 3 students (Aaron, Dale and Fabian) in 2009
  * 1 student (Addison) in 2010

* `The Space Telescope Science Institute <http://www.stsci.edu/portal/>`_: STScI hosted 1 GSoC 2007 student (Mateusz)

* Several 13-17 year old pre-university students contributed as part of
  Google's `Code-In
  <http://www.google-melange.com/gci/homepage/google/gci2011>`_ 2011.  (`GCI
  2011 <http://www.google-melange.com/gci/org/google/gci2011/sympy>`_)

* `Simula Research Laboratory <http://www.simula.no/>`_: supports Pearu Peterson work in SymPy/SymPy Core projects

* `GitHub <https://github.com/about>`_ is providing us with development
  and collaboration tools

License
-------

Unless stated otherwise, all files in the SymPy project, SymPy's webpage (and
wiki), all images and all documentation including this User's Guide are licensed
using the new BSD license:

.. literalinclude:: ../../LICENSE
